'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_ARB_uniform_buffer_object'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_ARB_uniform_buffer_object',error_checker=_errors._error_checker)
GL_ACTIVE_UNIFORM_BLOCKS=_C('GL_ACTIVE_UNIFORM_BLOCKS',0x8A36)
GL_ACTIVE_UNIFORM_BLOCK_MAX_NAME_LENGTH=_C('GL_ACTIVE_UNIFORM_BLOCK_MAX_NAME_LENGTH',0x8A35)
GL_INVALID_INDEX=_C('GL_INVALID_INDEX',0xFFFFFFFF)
GL_MAX_COMBINED_FRAGMENT_UNIFORM_COMPONENTS=_C('GL_MAX_COMBINED_FRAGMENT_UNIFORM_COMPONENTS',0x8A33)
GL_MAX_COMBINED_GEOMETRY_UNIFORM_COMPONENTS=_C('GL_MAX_COMBINED_GEOMETRY_UNIFORM_COMPONENTS',0x8A32)
GL_MAX_COMBINED_UNIFORM_BLOCKS=_C('GL_MAX_COMBINED_UNIFORM_BLOCKS',0x8A2E)
GL_MAX_COMBINED_VERTEX_UNIFORM_COMPONENTS=_C('GL_MAX_COMBINED_VERTEX_UNIFORM_COMPONENTS',0x8A31)
GL_MAX_FRAGMENT_UNIFORM_BLOCKS=_C('GL_MAX_FRAGMENT_UNIFORM_BLOCKS',0x8A2D)
GL_MAX_GEOMETRY_UNIFORM_BLOCKS=_C('GL_MAX_GEOMETRY_UNIFORM_BLOCKS',0x8A2C)
GL_MAX_UNIFORM_BLOCK_SIZE=_C('GL_MAX_UNIFORM_BLOCK_SIZE',0x8A30)
GL_MAX_UNIFORM_BUFFER_BINDINGS=_C('GL_MAX_UNIFORM_BUFFER_BINDINGS',0x8A2F)
GL_MAX_VERTEX_UNIFORM_BLOCKS=_C('GL_MAX_VERTEX_UNIFORM_BLOCKS',0x8A2B)
GL_UNIFORM_ARRAY_STRIDE=_C('GL_UNIFORM_ARRAY_STRIDE',0x8A3C)
GL_UNIFORM_BLOCK_ACTIVE_UNIFORMS=_C('GL_UNIFORM_BLOCK_ACTIVE_UNIFORMS',0x8A42)
GL_UNIFORM_BLOCK_ACTIVE_UNIFORM_INDICES=_C('GL_UNIFORM_BLOCK_ACTIVE_UNIFORM_INDICES',0x8A43)
GL_UNIFORM_BLOCK_BINDING=_C('GL_UNIFORM_BLOCK_BINDING',0x8A3F)
GL_UNIFORM_BLOCK_DATA_SIZE=_C('GL_UNIFORM_BLOCK_DATA_SIZE',0x8A40)
GL_UNIFORM_BLOCK_INDEX=_C('GL_UNIFORM_BLOCK_INDEX',0x8A3A)
GL_UNIFORM_BLOCK_NAME_LENGTH=_C('GL_UNIFORM_BLOCK_NAME_LENGTH',0x8A41)
GL_UNIFORM_BLOCK_REFERENCED_BY_FRAGMENT_SHADER=_C('GL_UNIFORM_BLOCK_REFERENCED_BY_FRAGMENT_SHADER',0x8A46)
GL_UNIFORM_BLOCK_REFERENCED_BY_GEOMETRY_SHADER=_C('GL_UNIFORM_BLOCK_REFERENCED_BY_GEOMETRY_SHADER',0x8A45)
GL_UNIFORM_BLOCK_REFERENCED_BY_VERTEX_SHADER=_C('GL_UNIFORM_BLOCK_REFERENCED_BY_VERTEX_SHADER',0x8A44)
GL_UNIFORM_BUFFER=_C('GL_UNIFORM_BUFFER',0x8A11)
GL_UNIFORM_BUFFER_BINDING=_C('GL_UNIFORM_BUFFER_BINDING',0x8A28)
GL_UNIFORM_BUFFER_OFFSET_ALIGNMENT=_C('GL_UNIFORM_BUFFER_OFFSET_ALIGNMENT',0x8A34)
GL_UNIFORM_BUFFER_SIZE=_C('GL_UNIFORM_BUFFER_SIZE',0x8A2A)
GL_UNIFORM_BUFFER_START=_C('GL_UNIFORM_BUFFER_START',0x8A29)
GL_UNIFORM_IS_ROW_MAJOR=_C('GL_UNIFORM_IS_ROW_MAJOR',0x8A3E)
GL_UNIFORM_MATRIX_STRIDE=_C('GL_UNIFORM_MATRIX_STRIDE',0x8A3D)
GL_UNIFORM_NAME_LENGTH=_C('GL_UNIFORM_NAME_LENGTH',0x8A39)
GL_UNIFORM_OFFSET=_C('GL_UNIFORM_OFFSET',0x8A3B)
GL_UNIFORM_SIZE=_C('GL_UNIFORM_SIZE',0x8A38)
GL_UNIFORM_TYPE=_C('GL_UNIFORM_TYPE',0x8A37)
@_f
@_p.types(None,_cs.GLuint,_cs.GLuint,_cs.GLsizei,arrays.GLsizeiArray,arrays.GLcharArray)
def glGetActiveUniformBlockName(program,uniformBlockIndex,bufSize,length,uniformBlockName):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLuint,_cs.GLenum,arrays.GLintArray)
def glGetActiveUniformBlockiv(program,uniformBlockIndex,pname,params):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLuint,_cs.GLsizei,arrays.GLsizeiArray,arrays.GLcharArray)
def glGetActiveUniformName(program,uniformIndex,bufSize,length,uniformName):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLsizei,arrays.GLuintArray,_cs.GLenum,arrays.GLintArray)
def glGetActiveUniformsiv(program,uniformCount,uniformIndices,pname,params):pass
@_f
@_p.types(_cs.GLuint,_cs.GLuint,arrays.GLcharArray)
def glGetUniformBlockIndex(program,uniformBlockName):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLsizei,ctypes.POINTER( ctypes.POINTER( _cs.GLchar )),arrays.GLuintArray)
def glGetUniformIndices(program,uniformCount,uniformNames,uniformIndices):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLuint,_cs.GLuint)
def glUniformBlockBinding(program,uniformBlockIndex,uniformBlockBinding):pass



'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.WGL import _types as _cs
# End users want this...
from OpenGL.raw.WGL._types import *
from OpenGL.raw.WGL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'WGL_ARB_pbuffer'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.WGL,'WGL_ARB_pbuffer',error_checker=_errors._error_checker)
WGL_DRAW_TO_PBUFFER_ARB=_C('WGL_DRAW_TO_PBUFFER_ARB',0x202D)
WGL_MAX_PBUFFER_HEIGHT_ARB=_C('WGL_MAX_PBUFFER_HEIGHT_ARB',0x2030)
WGL_MAX_PBUFFER_PIXELS_ARB=_C('WGL_MAX_PBUFFER_PIXELS_ARB',0x202E)
WGL_MAX_PBUFFER_WIDTH_ARB=_C('WGL_MAX_PBUFFER_WIDTH_ARB',0x202F)
WGL_PBUFFER_HEIGHT_ARB=_C('WGL_PBUFFER_HEIGHT_ARB',0x2035)
WGL_PBUFFER_LARGEST_ARB=_C('WGL_PBUFFER_LARGEST_ARB',0x2033)
WGL_PBUFFER_LOST_ARB=_C('WGL_PBUFFER_LOST_ARB',0x2036)
WGL_PBUFFER_WIDTH_ARB=_C('WGL_PBUFFER_WIDTH_ARB',0x2034)
@_f
@_p.types(_cs.HPBUFFERARB,_cs.HDC,_cs.c_int,_cs.c_int,_cs.c_int,ctypes.POINTER(_cs.c_int))
def wglCreatePbufferARB(hDC,iPixelFormat,iWidth,iHeight,piAttribList):pass
@_f
@_p.types(_cs.BOOL,_cs.HPBUFFERARB)
def wglDestroyPbufferARB(hPbuffer):pass
@_f
@_p.types(_cs.HDC,_cs.HPBUFFERARB)
def wglGetPbufferDCARB(hPbuffer):pass
@_f
@_p.types(_cs.BOOL,_cs.HPBUFFERARB,_cs.c_int,ctypes.POINTER(_cs.c_int))
def wglQueryPbufferARB(hPbuffer,iAttribute,piValue):pass
@_f
@_p.types(_cs.c_int,_cs.HPBUFFERARB,_cs.HDC)
def wglReleasePbufferDCARB(hPbuffer,hDC):pass



'''OpenGL extension EXT.fog_coord

This module customises the behaviour of the 
OpenGL.raw.GL.EXT.fog_coord to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension allows specifying an explicit per-vertex fog
	coordinate to be used in fog computations, rather than using a
	fragment depth-based fog equation.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/EXT/fog_coord.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.EXT.fog_coord import *
from OpenGL.raw.GL.EXT.fog_coord import _EXTENSION_NAME

def glInitFogCoordEXT():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )

glFogCoordfvEXT=wrapper.wrapper(glFogCoordfvEXT).setInputArraySize(
    'coord', 1
)
glFogCoorddvEXT=wrapper.wrapper(glFogCoorddvEXT).setInputArraySize(
    'coord', 1
)
# INPUT glFogCoordPointerEXT.pointer size not checked against 'type,stride'
glFogCoordPointerEXT=wrapper.wrapper(glFogCoordPointerEXT).setInputArraySize(
    'pointer', None
)
### END AUTOGENERATED SECTION


'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_NV_present_video'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_NV_present_video',error_checker=_errors._error_checker)
GL_CURRENT_TIME_NV=_C('GL_CURRENT_TIME_NV',0x8E28)
GL_FIELDS_NV=_C('GL_FIELDS_NV',0x8E27)
GL_FRAME_NV=_C('GL_FRAME_NV',0x8E26)
GL_NUM_FILL_STREAMS_NV=_C('GL_NUM_FILL_STREAMS_NV',0x8E29)
GL_PRESENT_DURATION_NV=_C('GL_PRESENT_DURATION_NV',0x8E2B)
GL_PRESENT_TIME_NV=_C('GL_PRESENT_TIME_NV',0x8E2A)
@_f
@_p.types(None,_cs.GLuint,_cs.GLenum,arrays.GLint64Array)
def glGetVideoi64vNV(video_slot,pname,params):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLenum,arrays.GLintArray)
def glGetVideoivNV(video_slot,pname,params):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLenum,arrays.GLuint64Array)
def glGetVideoui64vNV(video_slot,pname,params):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLenum,arrays.GLuintArray)
def glGetVideouivNV(video_slot,pname,params):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLuint64EXT,_cs.GLuint,_cs.GLuint,_cs.GLenum,_cs.GLenum,_cs.GLuint,_cs.GLenum,_cs.GLuint,_cs.GLenum,_cs.GLuint,_cs.GLenum,_cs.GLuint)
def glPresentFrameDualFillNV(video_slot,minPresentTime,beginPresentTimeId,presentDurationId,type,target0,fill0,target1,fill1,target2,fill2,target3,fill3):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLuint64EXT,_cs.GLuint,_cs.GLuint,_cs.GLenum,_cs.GLenum,_cs.GLuint,_cs.GLuint,_cs.GLenum,_cs.GLuint,_cs.GLuint)
def glPresentFrameKeyedNV(video_slot,minPresentTime,beginPresentTimeId,presentDurationId,type,target0,fill0,key0,target1,fill1,key1):pass



'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_EXT_texture_integer'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_EXT_texture_integer',error_checker=_errors._error_checker)
GL_ALPHA16I_EXT=_C('GL_ALPHA16I_EXT',0x8D8A)
GL_ALPHA16UI_EXT=_C('GL_ALPHA16UI_EXT',0x8D78)
GL_ALPHA32I_EXT=_C('GL_ALPHA32I_EXT',0x8D84)
GL_ALPHA32UI_EXT=_C('GL_ALPHA32UI_EXT',0x8D72)
GL_ALPHA8I_EXT=_C('GL_ALPHA8I_EXT',0x8D90)
GL_ALPHA8UI_EXT=_C('GL_ALPHA8UI_EXT',0x8D7E)
GL_ALPHA_INTEGER_EXT=_C('GL_ALPHA_INTEGER_EXT',0x8D97)
GL_BGRA_INTEGER_EXT=_C('GL_BGRA_INTEGER_EXT',0x8D9B)
GL_BGR_INTEGER_EXT=_C('GL_BGR_INTEGER_EXT',0x8D9A)
GL_BLUE_INTEGER_EXT=_C('GL_BLUE_INTEGER_EXT',0x8D96)
GL_GREEN_INTEGER_EXT=_C('GL_GREEN_INTEGER_EXT',0x8D95)
GL_INTENSITY16I_EXT=_C('GL_INTENSITY16I_EXT',0x8D8B)
GL_INTENSITY16UI_EXT=_C('GL_INTENSITY16UI_EXT',0x8D79)
GL_INTENSITY32I_EXT=_C('GL_INTENSITY32I_EXT',0x8D85)
GL_INTENSITY32UI_EXT=_C('GL_INTENSITY32UI_EXT',0x8D73)
GL_INTENSITY8I_EXT=_C('GL_INTENSITY8I_EXT',0x8D91)
GL_INTENSITY8UI_EXT=_C('GL_INTENSITY8UI_EXT',0x8D7F)
GL_LUMINANCE16I_EXT=_C('GL_LUMINANCE16I_EXT',0x8D8C)
GL_LUMINANCE16UI_EXT=_C('GL_LUMINANCE16UI_EXT',0x8D7A)
GL_LUMINANCE32I_EXT=_C('GL_LUMINANCE32I_EXT',0x8D86)
GL_LUMINANCE32UI_EXT=_C('GL_LUMINANCE32UI_EXT',0x8D74)
GL_LUMINANCE8I_EXT=_C('GL_LUMINANCE8I_EXT',0x8D92)
GL_LUMINANCE8UI_EXT=_C('GL_LUMINANCE8UI_EXT',0x8D80)
GL_LUMINANCE_ALPHA16I_EXT=_C('GL_LUMINANCE_ALPHA16I_EXT',0x8D8D)
GL_LUMINANCE_ALPHA16UI_EXT=_C('GL_LUMINANCE_ALPHA16UI_EXT',0x8D7B)
GL_LUMINANCE_ALPHA32I_EXT=_C('GL_LUMINANCE_ALPHA32I_EXT',0x8D87)
GL_LUMINANCE_ALPHA32UI_EXT=_C('GL_LUMINANCE_ALPHA32UI_EXT',0x8D75)
GL_LUMINANCE_ALPHA8I_EXT=_C('GL_LUMINANCE_ALPHA8I_EXT',0x8D93)
GL_LUMINANCE_ALPHA8UI_EXT=_C('GL_LUMINANCE_ALPHA8UI_EXT',0x8D81)
GL_LUMINANCE_ALPHA_INTEGER_EXT=_C('GL_LUMINANCE_ALPHA_INTEGER_EXT',0x8D9D)
GL_LUMINANCE_INTEGER_EXT=_C('GL_LUMINANCE_INTEGER_EXT',0x8D9C)
GL_RED_INTEGER_EXT=_C('GL_RED_INTEGER_EXT',0x8D94)
GL_RGB16I_EXT=_C('GL_RGB16I_EXT',0x8D89)
GL_RGB16UI_EXT=_C('GL_RGB16UI_EXT',0x8D77)
GL_RGB32I_EXT=_C('GL_RGB32I_EXT',0x8D83)
GL_RGB32UI_EXT=_C('GL_RGB32UI_EXT',0x8D71)
GL_RGB8I_EXT=_C('GL_RGB8I_EXT',0x8D8F)
GL_RGB8UI_EXT=_C('GL_RGB8UI_EXT',0x8D7D)
GL_RGBA16I_EXT=_C('GL_RGBA16I_EXT',0x8D88)
GL_RGBA16UI_EXT=_C('GL_RGBA16UI_EXT',0x8D76)
GL_RGBA32I_EXT=_C('GL_RGBA32I_EXT',0x8D82)
GL_RGBA32UI_EXT=_C('GL_RGBA32UI_EXT',0x8D70)
GL_RGBA8I_EXT=_C('GL_RGBA8I_EXT',0x8D8E)
GL_RGBA8UI_EXT=_C('GL_RGBA8UI_EXT',0x8D7C)
GL_RGBA_INTEGER_EXT=_C('GL_RGBA_INTEGER_EXT',0x8D99)
GL_RGBA_INTEGER_MODE_EXT=_C('GL_RGBA_INTEGER_MODE_EXT',0x8D9E)
GL_RGB_INTEGER_EXT=_C('GL_RGB_INTEGER_EXT',0x8D98)
@_f
@_p.types(None,_cs.GLint,_cs.GLint,_cs.GLint,_cs.GLint)
def glClearColorIiEXT(red,green,blue,alpha):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLuint,_cs.GLuint,_cs.GLuint)
def glClearColorIuiEXT(red,green,blue,alpha):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLintArray)
def glGetTexParameterIivEXT(target,pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLuintArray)
def glGetTexParameterIuivEXT(target,pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLintArray)
def glTexParameterIivEXT(target,pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLuintArray)
def glTexParameterIuivEXT(target,pname,params):pass



'''OpenGL extension ARB.transpose_matrix

This module customises the behaviour of the 
OpenGL.raw.GL.ARB.transpose_matrix to provide a more 
Python-friendly API

Overview (from the spec)
	
	New functions and tokens are added allowing application matrices
	stored in row major order rather than column major order to be
	transferred to the OpenGL implementation.  This allows an application
	to use standard C-language 2-dimensional arrays (m[row][col]) and
	have the array indices match the expected matrix row and column indexes.
	These arrays are referred to as transpose matrices since they are
	the transpose of the standard matrices passed to OpenGL.
	
	This extension adds an interface for transfering data to and from the
	OpenGL pipeline, it does not change any OpenGL processing or imply any
	changes in state representation.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/ARB/transpose_matrix.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.ARB.transpose_matrix import *
from OpenGL.raw.GL.ARB.transpose_matrix import _EXTENSION_NAME

def glInitTransposeMatrixARB():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )

glLoadTransposeMatrixfARB=wrapper.wrapper(glLoadTransposeMatrixfARB).setInputArraySize(
    'm', 16
)
glLoadTransposeMatrixdARB=wrapper.wrapper(glLoadTransposeMatrixdARB).setInputArraySize(
    'm', 16
)
glMultTransposeMatrixfARB=wrapper.wrapper(glMultTransposeMatrixfARB).setInputArraySize(
    'm', 16
)
glMultTransposeMatrixdARB=wrapper.wrapper(glMultTransposeMatrixdARB).setInputArraySize(
    'm', 16
)
### END AUTOGENERATED SECTION



'''OpenGL extension ARB.point_parameters

This module customises the behaviour of the 
OpenGL.raw.GL.ARB.point_parameters to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension supports additional geometric characteristics of
	points. It can be used to render particles or tiny light sources,
	commonly referred to as "Light points".
	
	The raster brightness of a point is a function of the point area,
	point color, point transparency, and the response of the display's
	electron gun and phosphor. The point area and the point transparency
	are derived from the point size, currently provided with the <size>
	parameter of glPointSize.
	
	The primary motivation is to allow the size of a point to be
	affected by distance attenuation. When distance attenuation has an
	effect, the final point size decreases as the distance of the point
	from the eye increases.
	
	The secondary motivation is a mean to control the mapping from the
	point size to the raster point area and point transparency. This is
	done in order to increase the dynamic range of the raster brightness
	of points. In other words, the alpha component of a point may be
	decreased (and its transparency increased) as its area shrinks below
	a defined threshold.
	
	This extension defines a derived point size to be closely related to
	point brightness. The brightness of a point is given by:
	
	                    1
	    dist_atten(d) = -------------------
	                    a + b * d + c * d^2
	
	    brightness(Pe) = Brightness * dist_atten(|Pe|)
	
	where 'Pe' is the point in eye coordinates, and 'Brightness' is some
	initial value proportional to the square of the size provided with
	PointSize. Here we simplify the raster brightness to be a function
	of the rasterized point area and point transparency.
	
	                brightness(Pe)       brightness(Pe) >= Threshold_Area
	    area(Pe) =
	                Threshold_Area       Otherwise
	
	    factor(Pe) = brightness(Pe)/Threshold_Area
	
	    alpha(Pe) = Alpha * factor(Pe)
	
	where 'Alpha' comes with the point color (possibly modified by
	lighting).
	
	'Threshold_Area' above is in area units. Thus, it is proportional to
	the square of the threshold provided by the programmer through this
	extension.
	
	The new point size derivation method applies to all points, while
	the threshold applies to multisample points only.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/ARB/point_parameters.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.ARB.point_parameters import *
from OpenGL.raw.GL.ARB.point_parameters import _EXTENSION_NAME

def glInitPointParametersARB():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )

# INPUT glPointParameterfvARB.params size not checked against 'pname'
glPointParameterfvARB=wrapper.wrapper(glPointParameterfvARB).setInputArraySize(
    'params', None
)
### END AUTOGENERATED SECTION




'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_ATI_vertex_array_object'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_ATI_vertex_array_object',error_checker=_errors._error_checker)
GL_ARRAY_OBJECT_BUFFER_ATI=_C('GL_ARRAY_OBJECT_BUFFER_ATI',0x8766)
GL_ARRAY_OBJECT_OFFSET_ATI=_C('GL_ARRAY_OBJECT_OFFSET_ATI',0x8767)
GL_DISCARD_ATI=_C('GL_DISCARD_ATI',0x8763)
GL_DYNAMIC_ATI=_C('GL_DYNAMIC_ATI',0x8761)
GL_OBJECT_BUFFER_SIZE_ATI=_C('GL_OBJECT_BUFFER_SIZE_ATI',0x8764)
GL_OBJECT_BUFFER_USAGE_ATI=_C('GL_OBJECT_BUFFER_USAGE_ATI',0x8765)
GL_PRESERVE_ATI=_C('GL_PRESERVE_ATI',0x8762)
GL_STATIC_ATI=_C('GL_STATIC_ATI',0x8760)
@_f
@_p.types(None,_cs.GLenum,_cs.GLint,_cs.GLenum,_cs.GLsizei,_cs.GLuint,_cs.GLuint)
def glArrayObjectATI(array,size,type,stride,buffer,offset):pass
@_f
@_p.types(None,_cs.GLuint)
def glFreeObjectBufferATI(buffer):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLfloatArray)
def glGetArrayObjectfvATI(array,pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLintArray)
def glGetArrayObjectivATI(array,pname,params):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLenum,arrays.GLfloatArray)
def glGetObjectBufferfvATI(buffer,pname,params):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLenum,arrays.GLintArray)
def glGetObjectBufferivATI(buffer,pname,params):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLenum,arrays.GLfloatArray)
def glGetVariantArrayObjectfvATI(id,pname,params):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLenum,arrays.GLintArray)
def glGetVariantArrayObjectivATI(id,pname,params):pass
@_f
@_p.types(_cs.GLboolean,_cs.GLuint)
def glIsObjectBufferATI(buffer):pass
@_f
@_p.types(_cs.GLuint,_cs.GLsizei,ctypes.c_void_p,_cs.GLenum)
def glNewObjectBufferATI(size,pointer,usage):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLuint,_cs.GLsizei,ctypes.c_void_p,_cs.GLenum)
def glUpdateObjectBufferATI(buffer,offset,size,pointer,preserve):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLenum,_cs.GLsizei,_cs.GLuint,_cs.GLuint)
def glVariantArrayObjectATI(id,type,stride,buffer,offset):pass



'''OpenGL extension ARB.shadow

This module customises the behaviour of the 
OpenGL.raw.GL.ARB.shadow to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension clarifies the GL_SGIX_shadow extension.
	
	This extension supports comparing the texture R coordinate to a depth
	texture value in order to produce a boolean texture value.  This can
	be used to implement shadow maps.
	
	The extension is written in generic terms such that other texture
	comparison modes can be accommodated in the future.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/ARB/shadow.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.ARB.shadow import *
from OpenGL.raw.GL.ARB.shadow import _EXTENSION_NAME

def glInitShadowARB():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION



'''OpenGL extension ARB.get_texture_sub_image

This module customises the behaviour of the 
OpenGL.raw.GL.ARB.get_texture_sub_image to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension adds a new function to get sub-regions of texture
	images.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/ARB/get_texture_sub_image.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.ARB.get_texture_sub_image import *
from OpenGL.raw.GL.ARB.get_texture_sub_image import _EXTENSION_NAME

def glInitGetTextureSubImageARB():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''OpenGL extension SGIS.point_line_texgen

This module customises the behaviour of the 
OpenGL.raw.GL.SGIS.point_line_texgen to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension adds two texture coordinate generation modes, both
	which generate a texture coordinate based on the minimum distance 
	from a vertex to a specified line.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/SGIS/point_line_texgen.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.SGIS.point_line_texgen import *
from OpenGL.raw.GL.SGIS.point_line_texgen import _EXTENSION_NAME

def glInitPointLineTexgenSGIS():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''OpenGL extension AMD.depth_clamp_separate

This module customises the behaviour of the 
OpenGL.raw.GL.AMD.depth_clamp_separate to provide a more 
Python-friendly API

Overview (from the spec)
	
	The extension ARB_depth_clamp introduced the ability to control
	the clamping of the depth value for both the near and far plane.
	One limitation is that the control was for both planes at the
	same time; some applications can benefit from having clamping
	enabled for only one of the two planes, in order to save
	fillrate for the other plane by clipping the geometry.
	
	This extension provides exactly such functionality.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/AMD/depth_clamp_separate.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.AMD.depth_clamp_separate import *
from OpenGL.raw.GL.AMD.depth_clamp_separate import _EXTENSION_NAME

def glInitDepthClampSeparateAMD():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''OpenGL extension REND.screen_coordinates

This module customises the behaviour of the 
OpenGL.raw.GL.REND.screen_coordinates to provide a more 
Python-friendly API

Overview (from the spec)
	
	    This extension allows the specification of screen coordinate vertex
	    data. Screen coordinate vertices completely bypass transformation,
	    texture generation, lighting and frustum clipping. It also allow for
	    fewer floating point computations to the performed by OpenGL.
	
	    If we get screen coordinate inputs then in order to perspectively
	    correct data (eg texture), the input data currently has to be
	    specified in one of the following manners
	
		1. Specify all the data normally
		   eg.
			  glTexture2T(s, t);
		   and the coordinates as
			  glVertex4T(x*w, y*w, z*w, w);
		or
		2. Divide each data by w
		   eg.
			  glTexture4T(s/w, t/w, r/w, q/w);
		   and the coordinates as
			  glVertex3T(x, y, z);
	
	    Most hardware already performs some form of correction of the
	    coordinate data with respect to the w term prior to interpolation.
	    This is normally in the form of a multiplication of the terms by the
	    inverse w. It would be much more efficient to simply specify screen
	    coordinates as shown in the following example
		   glTexture2T(s, t, r, q);
	    and the coordinates as
		   glVertex4T(x, y, z, w);
	    and allow the hardware to bring the interpolated terms into a linear
	    screen space.
	
	    Additionally if the application derives screen coordinates it is
	    also highly likely that the 1/w term may already be computed. So it
	    would be advantageous to be able to specify 1/w directly instead of
	    w in the input screen coordinates.
	
	    For hardware that linearly interpolates data, the hardware
	    interpolates the following data:
		s/w, t/w, r/w, q/w, x, y, z
	    If the input w represents the original 1/w, then the hardware can
	    avoid the division and instead interpolate:
		s*w, t*w, r*w, q*w, x, y, z
	

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/REND/screen_coordinates.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.REND.screen_coordinates import *
from OpenGL.raw.GL.REND.screen_coordinates import _EXTENSION_NAME

def glInitScreenCoordinatesREND():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''OpenGL extension ARB.shadow_ambient

This module customises the behaviour of the 
OpenGL.raw.GL.ARB.shadow_ambient to provide a more 
Python-friendly API

Overview (from the spec)
	
	This is based on the GL_SGIX_shadow_ambient extension and is layered
	upon the GL_ARB_shadow extension.
	
	Basically, this extension allows the user to specify the texture
	value to use when the texture compare function fails.  Normally
	this value is zero.  By allowing an arbitrary value we can get
	functionality which otherwise requires an advanced texture
	combine extension (such as GL_NV_register_combiners) and multiple
	texture units.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/ARB/shadow_ambient.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.ARB.shadow_ambient import *
from OpenGL.raw.GL.ARB.shadow_ambient import _EXTENSION_NAME

def glInitShadowAmbientARB():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GLES1 import _types as _cs
# End users want this...
from OpenGL.raw.GLES1._types import *
from OpenGL.raw.GLES1 import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GLES1_EXT_texture_storage'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GLES1,'GLES1_EXT_texture_storage',error_checker=_errors._error_checker)
GL_ALPHA16F_EXT=_C('GL_ALPHA16F_EXT',0x881C)
GL_ALPHA32F_EXT=_C('GL_ALPHA32F_EXT',0x8816)
GL_ALPHA8_EXT=_C('GL_ALPHA8_EXT',0x803C)
GL_BGRA8_EXT=_C('GL_BGRA8_EXT',0x93A1)
GL_LUMINANCE16F_EXT=_C('GL_LUMINANCE16F_EXT',0x881E)
GL_LUMINANCE32F_EXT=_C('GL_LUMINANCE32F_EXT',0x8818)
GL_LUMINANCE8_ALPHA8_EXT=_C('GL_LUMINANCE8_ALPHA8_EXT',0x8045)
GL_LUMINANCE8_EXT=_C('GL_LUMINANCE8_EXT',0x8040)
GL_LUMINANCE_ALPHA16F_EXT=_C('GL_LUMINANCE_ALPHA16F_EXT',0x881F)
GL_LUMINANCE_ALPHA32F_EXT=_C('GL_LUMINANCE_ALPHA32F_EXT',0x8819)
GL_R16F_EXT=_C('GL_R16F_EXT',0x822D)
GL_R32F_EXT=_C('GL_R32F_EXT',0x822E)
GL_R8_EXT=_C('GL_R8_EXT',0x8229)
GL_RG16F_EXT=_C('GL_RG16F_EXT',0x822F)
GL_RG32F_EXT=_C('GL_RG32F_EXT',0x8230)
GL_RG8_EXT=_C('GL_RG8_EXT',0x822B)
GL_RGB10_A2_EXT=_C('GL_RGB10_A2_EXT',0x8059)
GL_RGB10_EXT=_C('GL_RGB10_EXT',0x8052)
GL_RGB16F_EXT=_C('GL_RGB16F_EXT',0x881B)
GL_RGB32F_EXT=_C('GL_RGB32F_EXT',0x8815)
GL_RGBA16F_EXT=_C('GL_RGBA16F_EXT',0x881A)
GL_RGBA32F_EXT=_C('GL_RGBA32F_EXT',0x8814)
GL_TEXTURE_IMMUTABLE_FORMAT_EXT=_C('GL_TEXTURE_IMMUTABLE_FORMAT_EXT',0x912F)
@_f
@_p.types(None,_cs.GLenum,_cs.GLsizei,_cs.GLenum,_cs.GLsizei)
def glTexStorage1DEXT(target,levels,internalformat,width):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLsizei,_cs.GLenum,_cs.GLsizei,_cs.GLsizei)
def glTexStorage2DEXT(target,levels,internalformat,width,height):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLsizei,_cs.GLenum,_cs.GLsizei,_cs.GLsizei,_cs.GLsizei)
def glTexStorage3DEXT(target,levels,internalformat,width,height,depth):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLenum,_cs.GLsizei,_cs.GLenum,_cs.GLsizei)
def glTextureStorage1DEXT(texture,target,levels,internalformat,width):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLenum,_cs.GLsizei,_cs.GLenum,_cs.GLsizei,_cs.GLsizei)
def glTextureStorage2DEXT(texture,target,levels,internalformat,width,height):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLenum,_cs.GLsizei,_cs.GLenum,_cs.GLsizei,_cs.GLsizei,_cs.GLsizei)
def glTextureStorage3DEXT(texture,target,levels,internalformat,width,height,depth):pass



'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_ARB_enhanced_layouts'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_ARB_enhanced_layouts',error_checker=_errors._error_checker)
GL_LOCATION_COMPONENT=_C('GL_LOCATION_COMPONENT',0x934A)
GL_TRANSFORM_FEEDBACK_BUFFER=_C('GL_TRANSFORM_FEEDBACK_BUFFER',0x8C8E)
GL_TRANSFORM_FEEDBACK_BUFFER_INDEX=_C('GL_TRANSFORM_FEEDBACK_BUFFER_INDEX',0x934B)
GL_TRANSFORM_FEEDBACK_BUFFER_STRIDE=_C('GL_TRANSFORM_FEEDBACK_BUFFER_STRIDE',0x934C)




'''OpenGL extension OES.framebuffer_object

This module customises the behaviour of the 
OpenGL.raw.GLES1.OES.framebuffer_object to provide a more 
Python-friendly API

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/OES/framebuffer_object.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GLES1 import _types, _glgets
from OpenGL.raw.GLES1.OES.framebuffer_object import *
from OpenGL.raw.GLES1.OES.framebuffer_object import _EXTENSION_NAME

def glInitFramebufferObjectOES():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )

# INPUT glDeleteRenderbuffersOES.renderbuffers size not checked against n
glDeleteRenderbuffersOES=wrapper.wrapper(glDeleteRenderbuffersOES).setInputArraySize(
    'renderbuffers', None
)
# INPUT glGenRenderbuffersOES.renderbuffers size not checked against n
glGenRenderbuffersOES=wrapper.wrapper(glGenRenderbuffersOES).setInputArraySize(
    'renderbuffers', None
)
# INPUT glGetRenderbufferParameterivOES.params size not checked against 'pname'
glGetRenderbufferParameterivOES=wrapper.wrapper(glGetRenderbufferParameterivOES).setInputArraySize(
    'params', None
)
# INPUT glDeleteFramebuffersOES.framebuffers size not checked against n
glDeleteFramebuffersOES=wrapper.wrapper(glDeleteFramebuffersOES).setInputArraySize(
    'framebuffers', None
)
# INPUT glGenFramebuffersOES.framebuffers size not checked against n
glGenFramebuffersOES=wrapper.wrapper(glGenFramebuffersOES).setInputArraySize(
    'framebuffers', None
)
# INPUT glGetFramebufferAttachmentParameterivOES.params size not checked against 'pname'
glGetFramebufferAttachmentParameterivOES=wrapper.wrapper(glGetFramebufferAttachmentParameterivOES).setInputArraySize(
    'params', None
)
### END AUTOGENERATED SECTION


'''OpenGL extension ARB.fragment_shader

This module customises the behaviour of the 
OpenGL.raw.GL.ARB.fragment_shader to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension adds functionality to define fragment shader objects. A
	fragment shader object is a shader object (see the ARB_shader_objects
	extension) that, when attached to a program object, can be compiled and
	linked to produce an executable that runs on the fragment processor in
	OpenGL. The fragment processor is a programmable unit that replaces the
	OpenGL 1.4 fixed-function texturing, color sum and fog stages. This
	extension also defines how such an executable interacts with the fixed
	functionality fragment processing of OpenGL 1.4. The language used to
	write fragment shaders is not discussed here. That language is defined
	in the OpenGL Shading Language specification as the Fragment Shading
	Language.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/ARB/fragment_shader.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.ARB.fragment_shader import *
from OpenGL.raw.GL.ARB.fragment_shader import _EXTENSION_NAME

def glInitFragmentShaderARB():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GLES2 import _types as _cs
# End users want this...
from OpenGL.raw.GLES2._types import *
from OpenGL.raw.GLES2 import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GLES2_EXT_draw_buffers'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GLES2,'GLES2_EXT_draw_buffers',error_checker=_errors._error_checker)
GL_COLOR_ATTACHMENT0_EXT=_C('GL_COLOR_ATTACHMENT0_EXT',0x8CE0)
GL_COLOR_ATTACHMENT10_EXT=_C('GL_COLOR_ATTACHMENT10_EXT',0x8CEA)
GL_COLOR_ATTACHMENT11_EXT=_C('GL_COLOR_ATTACHMENT11_EXT',0x8CEB)
GL_COLOR_ATTACHMENT12_EXT=_C('GL_COLOR_ATTACHMENT12_EXT',0x8CEC)
GL_COLOR_ATTACHMENT13_EXT=_C('GL_COLOR_ATTACHMENT13_EXT',0x8CED)
GL_COLOR_ATTACHMENT14_EXT=_C('GL_COLOR_ATTACHMENT14_EXT',0x8CEE)
GL_COLOR_ATTACHMENT15_EXT=_C('GL_COLOR_ATTACHMENT15_EXT',0x8CEF)
GL_COLOR_ATTACHMENT1_EXT=_C('GL_COLOR_ATTACHMENT1_EXT',0x8CE1)
GL_COLOR_ATTACHMENT2_EXT=_C('GL_COLOR_ATTACHMENT2_EXT',0x8CE2)
GL_COLOR_ATTACHMENT3_EXT=_C('GL_COLOR_ATTACHMENT3_EXT',0x8CE3)
GL_COLOR_ATTACHMENT4_EXT=_C('GL_COLOR_ATTACHMENT4_EXT',0x8CE4)
GL_COLOR_ATTACHMENT5_EXT=_C('GL_COLOR_ATTACHMENT5_EXT',0x8CE5)
GL_COLOR_ATTACHMENT6_EXT=_C('GL_COLOR_ATTACHMENT6_EXT',0x8CE6)
GL_COLOR_ATTACHMENT7_EXT=_C('GL_COLOR_ATTACHMENT7_EXT',0x8CE7)
GL_COLOR_ATTACHMENT8_EXT=_C('GL_COLOR_ATTACHMENT8_EXT',0x8CE8)
GL_COLOR_ATTACHMENT9_EXT=_C('GL_COLOR_ATTACHMENT9_EXT',0x8CE9)
GL_DRAW_BUFFER0_EXT=_C('GL_DRAW_BUFFER0_EXT',0x8825)
GL_DRAW_BUFFER10_EXT=_C('GL_DRAW_BUFFER10_EXT',0x882F)
GL_DRAW_BUFFER11_EXT=_C('GL_DRAW_BUFFER11_EXT',0x8830)
GL_DRAW_BUFFER12_EXT=_C('GL_DRAW_BUFFER12_EXT',0x8831)
GL_DRAW_BUFFER13_EXT=_C('GL_DRAW_BUFFER13_EXT',0x8832)
GL_DRAW_BUFFER14_EXT=_C('GL_DRAW_BUFFER14_EXT',0x8833)
GL_DRAW_BUFFER15_EXT=_C('GL_DRAW_BUFFER15_EXT',0x8834)
GL_DRAW_BUFFER1_EXT=_C('GL_DRAW_BUFFER1_EXT',0x8826)
GL_DRAW_BUFFER2_EXT=_C('GL_DRAW_BUFFER2_EXT',0x8827)
GL_DRAW_BUFFER3_EXT=_C('GL_DRAW_BUFFER3_EXT',0x8828)
GL_DRAW_BUFFER4_EXT=_C('GL_DRAW_BUFFER4_EXT',0x8829)
GL_DRAW_BUFFER5_EXT=_C('GL_DRAW_BUFFER5_EXT',0x882A)
GL_DRAW_BUFFER6_EXT=_C('GL_DRAW_BUFFER6_EXT',0x882B)
GL_DRAW_BUFFER7_EXT=_C('GL_DRAW_BUFFER7_EXT',0x882C)
GL_DRAW_BUFFER8_EXT=_C('GL_DRAW_BUFFER8_EXT',0x882D)
GL_DRAW_BUFFER9_EXT=_C('GL_DRAW_BUFFER9_EXT',0x882E)
GL_MAX_COLOR_ATTACHMENTS_EXT=_C('GL_MAX_COLOR_ATTACHMENTS_EXT',0x8CDF)
GL_MAX_DRAW_BUFFERS_EXT=_C('GL_MAX_DRAW_BUFFERS_EXT',0x8824)
@_f
@_p.types(None,_cs.GLsizei,arrays.GLuintArray)
def glDrawBuffersEXT(n,bufs):pass



'''OpenGL extension APPLE.flush_buffer_range

This module customises the behaviour of the 
OpenGL.raw.GL.APPLE.flush_buffer_range to provide a more 
Python-friendly API

Overview (from the spec)
	
	APPLE_flush_buffer_range expands the buffer object API to allow greater
	performance when a client application only needs to write to a sub-range
	of a buffer object. To that end, this extension introduces two new buffer
	object features: non-serialized buffer modification and explicit sub-range
	flushing for mapped buffer objects.
	
	OpenGL requires that commands occur in a FIFO manner meaning that any
	changes to buffer objects either block until the data has been processed by
	the OpenGL pipeline or else create extra copies to avoid such a block.  By
	providing a method to asynchronously modify buffer object data, an
	application is then able to manage the synchronization points themselves
	and modify ranges of data contained by a buffer object even though OpenGL
	might still be using other parts of it.
	
	This extension also provides a method for explicitly flushing ranges of a
	mapped buffer object so OpenGL does not have to assume that the entire
	range may have been modified.
	
	Affects ARB_vertex_buffer_object, ARB_pixel_buffer_object and OpenGL 1.5
	Buffer Objects.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/APPLE/flush_buffer_range.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.APPLE.flush_buffer_range import *
from OpenGL.raw.GL.APPLE.flush_buffer_range import _EXTENSION_NAME

def glInitFlushBufferRangeAPPLE():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''OpenGL extension NV.packed_depth_stencil

This module customises the behaviour of the 
OpenGL.raw.GL.NV.packed_depth_stencil to provide a more 
Python-friendly API

Overview (from the spec)
	
	Many OpenGL implementations have chosen to interleave the depth and
	stencil buffers into one buffer, often with 24 bits of depth
	precision and 8 bits of stencil data.  32 bits is more than is needed
	for the depth buffer much of the time; a 24-bit depth buffer, on the
	other hand, requires that reads and writes of depth data be unaligned
	with respect to power-of-two boundaries.  On the other hand, 8 bits
	of stencil data is more than sufficient for most applications, so it
	is only natural to pack the two buffers into a single buffer with
	both depth and stencil data.  OpenGL never provides direct access to
	the buffers, so the OpenGL implementation can provide an interface to
	applications where it appears the one merged buffer is composed of
	two logical buffers.
	
	One disadvantage of this scheme is that OpenGL lacks any means by
	which this packed data can be handled efficiently.  For example, when
	an application reads from the 24-bit depth buffer, using the type
	GL_UNSIGNED_SHORT will lose 8 bits of data, while GL_UNSIGNED_INT has
	8 too many.  Both require expensive format conversion operations.  A
	24-bit format would be no more suitable, because it would also suffer
	from the unaligned memory accesses that made the standalone 24-bit
	depth buffer an unattractive proposition in the first place.
	
	Many applications, such as parallel rendering applications, may also
	wish to draw to or read back from both the depth and stencil buffers
	at the same time.  Currently this requires two separate operations,
	reducing performance.  Since the buffers are interleaved, drawing to
	or reading from both should be no more expensive than using just one;
	in some cases, it may even be cheaper.
	
	This extension provides a new data format, GL_DEPTH_STENCIL_NV, that
	can be used with the glDrawPixels, glReadPixels, and glCopyPixels
	commands, as well as a packed data type, GL_UNSIGNED_INT_24_8_NV,
	that is meant to be used with GL_DEPTH_STENCIL_NV.  No other formats
	are supported with GL_DEPTH_STENCIL_NV.  If SGIX_depth_texture is
	supported, GL_DEPTH_STENCIL_NV/GL_UNSIGNED_INT_24_8_NV data can also
	be used for textures; this provides a more efficient way to supply
	data for a 24-bit depth texture.
	
	GL_DEPTH_STENCIL_NV data, when passed through the pixel path,
	undergoes both depth and stencil operations.  The depth data is
	scaled and biased by the current GL_DEPTH_SCALE and GL_DEPTH_BIAS,
	while the stencil data is shifted and offset by the current
	GL_INDEX_SHIFT and GL_INDEX_OFFSET.  The stencil data is also put
	through the stencil-to-stencil pixel map.
	
	glDrawPixels of GL_DEPTH_STENCIL_NV data operates similarly to that
	of GL_STENCIL_INDEX data, bypassing the OpenGL fragment pipeline
	entirely, unlike the treatment of GL_DEPTH_COMPONENT data.  The
	stencil and depth masks are applied, as are the pixel ownership and
	scissor tests, but all other operations are skipped.
	
	glReadPixels of GL_DEPTH_STENCIL_NV data reads back a rectangle from
	both the depth and stencil buffers.
	
	glCopyPixels of GL_DEPTH_STENCIL_NV data copies a rectangle from
	both the depth and stencil buffers.  Like glDrawPixels, it applies
	both the stencil and depth masks but skips the remainder of the
	OpenGL fragment pipeline.
	
	glTex[Sub]Image[1,2,3]D of GL_DEPTH_STENCIL_NV data loads depth data
	into a depth texture.  glGetTexImage of GL_DEPTH_STENCIL_NV data can
	be used to retrieve depth data from a depth texture.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/NV/packed_depth_stencil.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.NV.packed_depth_stencil import *
from OpenGL.raw.GL.NV.packed_depth_stencil import _EXTENSION_NAME

def glInitPackedDepthStencilNV():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION
# Setup the new image types
from OpenGL import images 
from OpenGL.raw.GL.VERSION.GL_1_1 import GL_UNSIGNED_INT
images.TYPE_TO_ARRAYTYPE[ GL_UNSIGNED_INT_24_8_NV ] = GL_UNSIGNED_INT
images.TIGHT_PACK_FORMATS[ GL_UNSIGNED_INT_24_8_NV ] = 4
images.COMPONENT_COUNTS[ GL_DEPTH_STENCIL_NV ] = 4



'''OpenGL extension ARB.half_float_pixel

This module customises the behaviour of the 
OpenGL.raw.GL.ARB.half_float_pixel to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension introduces a new data type for half-precision (16-bit)
	floating-point quantities.  The floating-point format is very similar
	to the IEEE single-precision floating-point standard, except that it
	has only 5 exponent bits and 10 mantissa bits.  Half-precision floats
	are smaller than full precision floats and provide a larger dynamic
	range than similarly sized normalized scalar data types.
	
	This extension allows applications to use half-precision floating-
	point data when specifying pixel data.  It extends the existing image
	specification commands to accept the new data type.
	
	Floating-point data is clamped to [0, 1] at various places in the
	GL unless clamping is disabled with the ARB_color_buffer_float
	extension.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/ARB/half_float_pixel.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.ARB.half_float_pixel import *
from OpenGL.raw.GL.ARB.half_float_pixel import _EXTENSION_NAME

def glInitHalfFloatPixelARB():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


"""OpenGL.EGL the portable interface to GL environments"""
from OpenGL.raw.GLES3._types import *
from OpenGL.GLES2.VERSION.GLES2_2_0 import *
from OpenGL.GLES3.VERSION.GLES3_3_0 import *
from OpenGL.GLES3.VERSION.GLES3_3_1 import *



"""Base class for the various Python data-format storage type APIs

Data-type handlers are specified using OpenGL.plugins module
"""
import ctypes
from OpenGL import plugins

class FormatHandler( object ):
    """Abstract class describing the handler interface
    
    Each data-type handler is responsible for providing a number of methods
    which allow it to manipulate (and create) instances of the data-type 
    it represents.
    """
    LAZY_TYPE_REGISTRY = {}  # more registrations
    HANDLER_REGISTRY = {}
    baseType = None
    typeConstant = None
    HANDLED_TYPES = ()
    preferredOutput = None
    isOutput = False
    GENERIC_OUTPUT_PREFERENCES = ['numpy','ctypesarrays']
    ALL_OUTPUT_HANDLERS = []
    def loadAll( cls ):
        """Load all OpenGL.plugins-registered FormatHandler classes
        """
        for entrypoint in plugins.FormatHandler.all():
            cls.loadPlugin( entrypoint )
    @classmethod
    def loadPlugin( cls, entrypoint ):
        """Load a single entry-point via plugins module"""
        if not entrypoint.loaded:
            from OpenGL.arrays.arraydatatype import ArrayDatatype
            try:
                plugin_class = entrypoint.load()
            except ImportError as err:
                from OpenGL import logs
                from OpenGL._configflags import WARN_ON_FORMAT_UNAVAILABLE
                _log = logs.getLog( 'OpenGL.formathandler' )
                if WARN_ON_FORMAT_UNAVAILABLE:
                    logFunc = _log.warn
                else:
                    logFunc = _log.info 
                logFunc(
                    'Unable to load registered array format handler %s:\n%s', 
                    entrypoint.name, _log.getException( err )
                )
            else:
                handler = plugin_class()
                #handler.register( handler.HANDLED_TYPES )
                ArrayDatatype.getRegistry()[ entrypoint.name ] = handler
                return handler
            entrypoint.loaded = True
    @classmethod
    def typeLookup( cls, type ):
        """Lookup handler by data-type"""
        registry = ArrayDatatype.getRegistry()
        try:
            return registry[ type ]
        except KeyError as err:
            key = '%s.%s'%(type.__module__,type.__name__)
            plugin = cls.LAZY_TYPE_REGISTRY.get( key )
            if plugin:
                cls.loadPlugin( plugin )
                return registry[ type ]
            raise KeyError( """Unable to find data-format handler for %s"""%( type,))
    loadAll = classmethod( loadAll )

    def register( self, types=None ):
        """Register this class as handler for given set of types"""
        from OpenGL.arrays.arraydatatype import ArrayDatatype
        ArrayDatatype.getRegistry().register( self, types )
    def registerReturn( self ):
        """Register this handler as the default return-type handler"""
        from OpenGL.arrays.arraydatatype import ArrayDatatype
        ArrayDatatype.getRegistry().registerReturn( self )

    def from_param( self, value, typeCode=None  ):
        """Convert to a ctypes pointer value"""
    def dataPointer( self, value ):
        """return long for pointer value"""
    def asArray( self, value, typeCode=None ):
        """Given a value, convert to array representation"""
    def arrayToGLType( self, value ):
        """Given a value, guess OpenGL type of the corresponding pointer"""
    def arraySize( self, value, typeCode = None ):
        """Given a data-value, calculate dimensions for the array"""
    def unitSize( self, value, typeCode=None ):
        """Determine unit size of an array (if possible)"""
        if self.baseType is not None:
            return 
    def dimensions( self, value, typeCode=None ):
        """Determine dimensions of the passed array value (if possible)"""



'''OpenGL extension EXT.gpu_program_parameters

This module customises the behaviour of the 
OpenGL.raw.GL.EXT.gpu_program_parameters to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension provides a new set of procedures to load multiple 
	consecutive program environment parameters more efficiently, via a single 
	GL call instead of multiple calls.  This will reduce the amount of CPU 
	overhead involved in loading parameters. 
	
	With the existing ARB_vertex_program and ARB_fragment_program APIs, 
	program parameters must be loaded one at a time, via separate calls. 
	While the NV_vertex_program extension provides a set of similar functions 
	that can be used to load program environment parameters (which are 
	equivalent to "program parameters" in NV_vertex_program), no such function 
	exists for program local parameters. 

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/EXT/gpu_program_parameters.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.EXT.gpu_program_parameters import *
from OpenGL.raw.GL.EXT.gpu_program_parameters import _EXTENSION_NAME

def glInitGpuProgramParametersEXT():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )

# INPUT glProgramEnvParameters4fvEXT.params size not checked against count*4
glProgramEnvParameters4fvEXT=wrapper.wrapper(glProgramEnvParameters4fvEXT).setInputArraySize(
    'params', None
)
# INPUT glProgramLocalParameters4fvEXT.params size not checked against count*4
glProgramLocalParameters4fvEXT=wrapper.wrapper(glProgramLocalParameters4fvEXT).setInputArraySize(
    'params', None
)
### END AUTOGENERATED SECTION


'''OpenGL extension NV.vertex_program3

This module customises the behaviour of the 
OpenGL.raw.GL.NV.vertex_program3 to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension, like the NV_vertex_program2_option extension,
	provides additional vertex program functionality to extend the
	standard ARB_vertex_program language and execution environment.
	ARB programs wishing to use this added functionality need only add:
	
	    OPTION NV_vertex_program3;
	
	to the beginning of their vertex programs.
	
	New functionality provided by this extension, above and beyond that
	already provided by NV_vertex_program2_option extension, includes: 
	
	    * texture lookups in vertex programs,
	
	    * ability to push and pop address registers on the stack,
	
	    * address register-relative addressing for vertex attribute and
	      result arrays, and
	
	    * a second four-component condition code.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/NV/vertex_program3.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.NV.vertex_program3 import *
from OpenGL.raw.GL.NV.vertex_program3 import _EXTENSION_NAME

def glInitVertexProgram3NV():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GLX import _types as _cs
# End users want this...
from OpenGL.raw.GLX._types import *
from OpenGL.raw.GLX import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GLX_INTEL_swap_event'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GLX,'GLX_INTEL_swap_event',error_checker=_errors._error_checker)
GLX_BUFFER_SWAP_COMPLETE_INTEL_MASK=_C('GLX_BUFFER_SWAP_COMPLETE_INTEL_MASK',0x04000000)
GLX_COPY_COMPLETE_INTEL=_C('GLX_COPY_COMPLETE_INTEL',0x8181)
GLX_EXCHANGE_COMPLETE_INTEL=_C('GLX_EXCHANGE_COMPLETE_INTEL',0x8180)
GLX_FLIP_COMPLETE_INTEL=_C('GLX_FLIP_COMPLETE_INTEL',0x8182)




'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_ARB_map_buffer_range'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_ARB_map_buffer_range',error_checker=_errors._error_checker)
GL_MAP_FLUSH_EXPLICIT_BIT=_C('GL_MAP_FLUSH_EXPLICIT_BIT',0x0010)
GL_MAP_INVALIDATE_BUFFER_BIT=_C('GL_MAP_INVALIDATE_BUFFER_BIT',0x0008)
GL_MAP_INVALIDATE_RANGE_BIT=_C('GL_MAP_INVALIDATE_RANGE_BIT',0x0004)
GL_MAP_READ_BIT=_C('GL_MAP_READ_BIT',0x0001)
GL_MAP_UNSYNCHRONIZED_BIT=_C('GL_MAP_UNSYNCHRONIZED_BIT',0x0020)
GL_MAP_WRITE_BIT=_C('GL_MAP_WRITE_BIT',0x0002)
@_f
@_p.types(None,_cs.GLenum,_cs.GLintptr,_cs.GLsizeiptr)
def glFlushMappedBufferRange(target,offset,length):pass
@_f
@_p.types(ctypes.c_void_p,_cs.GLenum,_cs.GLintptr,_cs.GLsizeiptr,_cs.GLbitfield)
def glMapBufferRange(target,offset,length,access):pass
